==> skyfish-0.60.tar.gz: skyfish-0.60/bin/skyfish.h <==
/*-
 * Copyright (c) 2008 Andrey V. Surkov <nsand@sura.ru>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	 $Id: skyfish.h,v 0.52 2008/05/23 07:54:36 nsand Exp $
 */
#ifndef _SKYFISH_TCP_
#define	_SKYFISH_TCP_

#include "my_types.h"
#include "parse_http.h"
#include "db.h"
#include "file_sky.h"
#include "interface.h"

int 	isok(void);
int 	initialize(void);
int 	handler(u_char * packet);

int 	CheckPath(void);
void 	timer_refresh(int signum);
void 	close_kb(void);
void 	EXIT();
void 	CloseProg (void);
void 	ChFastScr(void);
u_short	tcp_cksum(const struct in_addr, const struct in_addr, 
			 u_char proto, u_short len,const char *hstart, u_short csum);
u_short	in_cksum3(const u_short *addr, register u_int len, int csum);
u_short	in_cksum(u_short *ptr,int nbytes);
u_char* SborkaIP(u_char packet);



#endif

==> skyfish-0.83.tar.gz: skyfish-0.83/bin/skyfish.h <==
/*-
 * Copyright (c) 2008 Andrey V. Surkov <nsand@sura.ru>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	 $Id: skyfish.h,v 0.52 2008/05/23 07:54:36 nsand Exp $
 */

#ifndef _SKYFISH_TCP_
#define	_SKYFISH_TCP_

#include "my_types.h"
#include "sky_node.h"
#include "parse_http.h"
#include "db.h"
#include "file_sky.h"
#include "interface.h"

#define INTERVAL 1		/* interrupt timer */

struct _pseudoheader {
struct in_addr source_addr;
struct in_addr destination_addr;
u_char zero; /* ##p# */
u_char protocol;
u_short length;
} pseudoheader;

void 	callme(int sig_no);
void 	CloseProg (void);
void 	ChFastScr(void);
int 	initialize(void);
int 	handler(const char * packet);
int	RegisterTimer(void);
void	TransformDBB(void);
inline 	u_short checksum(const u_char* d, int l, u_long c);
u_short	tcp_cksum(const struct in_addr, const struct in_addr, 
			 u_char proto, u_short len,const char *hstart, u_short csum);
u_short	in_cksumip(const u_short *addr, register u_int len, int csum);
u_short	in_cksum(u_short *ptr,int nbytes);

inline u_short tcp_checksum3(u_short *addr, int len);
#endif
